/******************** (C) COPYRIGHT 2007 STMicroelectronics ********************
* File Name          : MC_Keys.c
* Author             : IMS Systems Lab 
* Date First Issued  : 21/11/07
* Description        : This file handles Joystick and button management
********************************************************************************
* History:
* 21/11/07 v1.0
********************************************************************************
* THE PRESENT SOFTWARE WHICH IS FOR GUIDANCE ONLY AIMS AT PROVIDING CUSTOMERS
* WITH CODING INFORMATION REGARDING THEIR PRODUCTS IN ORDER FOR THEM TO SAVE TIME.
* AS A RESULT, STMICROELECTRONICS SHALL NOT BE HELD LIABLE FOR ANY DIRECT, 
* INDIRECT OR CONSEQUENTIAL DAMAGES WITH RESPECT TO ANY CLAIMS ARISING FROM THE
* CONTENT OF SUCH SOFTWARE AND/OR THE USE MADE BY CUSTOMERS OF THE CODING 
* INFORMATION CONTAINED HEREIN IN CONNECTION WITH THEIR PRODUCTS.
*******************************************************************************/
/* Includes ------------------------------------------------------------------*/
#include "stm32f10x_lib.h"
#include "stm32f10x_MClib.h"
#include "MC_Globals.h"



/* Private typedef -----------------------------------------------------------*/
/* Private define ------------------------------------------------------------*/
#define KEY_PORT GPIOB
#define KEY_ON_BIT 		 	GPIO_Pin_8
#define KEY_PLUS_BIT  		GPIO_Pin_9
#define KEY_MINUS_BIT  		GPIO_Pin_10
#define KEY_MASK			(KEY_ON_BIT|KEY_PLUS_BIT|KEY_MINUS_BIT)




/*4 key state in key FSM mode*/
enum
{
   KEY_STATE_0=0,  //wait trigger
   KEY_STATE_1,	   //key press wait to comfirm
   KEY_STATE_2,	   //delay count_1
   KEY_STATE_3	   //delay count_2
  
};

//key dely 1s,Sequence key trigger time delay 500ms

#define SPEED_INC_DEC     	200
#define KEY_DELAY		  	500	


/* Private macro -------------------------------------------------------------*/
/* Private variables ---------------------------------------------------------*/




/*******************************************************************************
* Function Name  : KEYS_Init
* Description    : Init GPIOs for joystick/button management
* Input          : None
* Output         : None
* Return         : None
*******************************************************************************/
void KEYS_Init(void)
{
  GPIO_InitTypeDef GPIO_InitStructure;
    
  /* EnableGPIOBclock */
  RCC_APB2PeriphClockCmd(RCC_APB2Periph_GPIOB, ENABLE);
 
  GPIO_StructInit(&GPIO_InitStructure);
  
  /*Key GPIOs configuration*/
  /*Input pull up-mode can save Res*/
  GPIO_InitStructure.GPIO_Pin = KEY_ON_BIT|KEY_PLUS_BIT|KEY_MINUS_BIT;
  GPIO_InitStructure.GPIO_Mode = GPIO_Mode_IPU;
  GPIO_Init(KEY_PORT, &GPIO_InitStructure);
  
  
}
  

/*******************************************************************************
* Function Name  : KEYS_Read
* Description    : Reads key from demoboard.FSM detect the key pad
* Input          : None
* Output         : None
* Return         : Return key_value
*******************************************************************************/

u8 KEYS_Read (void)
{
  static u8 key_state=	KEY_STATE_0;
  static u32 bKey_Port_current;
  static u32 bKey_Port_previous=KEY_MASK;
  u8 key_return=NOTHING;
  bKey_Port_current= KEY_MASK&GPIO_ReadInputData(KEY_PORT);
  switch(key_state)
  {
  	case KEY_STATE_0:
	//key press waite comfirm
	 	if((bKey_Port_current!=KEY_MASK)/*&&(bKey_Port_current==bKey_Port_previous)*/) key_state=KEY_STATE_1;
	 	break;
	case KEY_STATE_1:
	//real key press,turn to delay_cout1 
	 	if(bKey_Port_previous==bKey_Port_current) 
			{ //ONOFF not use sequence trigger mode
			 if(!(bKey_Port_current&KEY_ON_BIT)) {key_return=ONOFF;DelayTimer(200);}
			 key_state=KEY_STATE_2;
			 StartTimer(TIMERKEY,KEY_DELAY);
			}
		else key_state=KEY_STATE_0;
		break;
   	case KEY_STATE_2:
	//real key press,and no delay for 1s 
		if(bKey_Port_current==KEY_MASK)
		 {	//PLUS,MINUS key 1/1,ONOFF key 1/0,iput(1:0 off:ON)/output	
		  if(!(bKey_Port_previous&KEY_PLUS_BIT)) 		key_return=PLUS;
		  else if(!(bKey_Port_previous&KEY_MINUS_BIT)) 	key_return=MINUS;
		  key_state=KEY_STATE_0;
		 }
	   else if(ReadTimer(TIMERKEY)==OK) 
			{ //PLUS,MINUS key 0/2,ONOFF key 0/0
			 if(!(bKey_Port_current&KEY_ON_BIT)) break;	
			 if(!(bKey_Port_current&KEY_PLUS_BIT)) 		 key_return=PLUS;
		     else if(!(bKey_Port_current&KEY_MINUS_BIT)) key_return=MINUS;
			 key_state=KEY_STATE_3;
		  	 StartTimer(TIMERKEY,SPEED_INC_DEC);
			}
		break;
	case KEY_STATE_3:
				//PLUS,MINUS 0/2
	 	if((bKey_Port_previous==bKey_Port_current)&&(ReadTimer(TIMERKEY)==OK)) 
			{
		  	if(!(bKey_Port_current&KEY_PLUS_BIT)) 		key_return=PLUS;
		  	else if(!(bKey_Port_current&KEY_MINUS_BIT)) key_return=MINUS;
		  	StartTimer(TIMERKEY,SPEED_INC_DEC);
			}
		else if(bKey_Port_previous!=bKey_Port_current)	//if(bKey_Port_previous!=bKey_Port_current) must used
			{
			 key_state=KEY_STATE_0;
			 StopTimer(TIMERKEY);
			}
		break;
  } 
  bKey_Port_previous=bKey_Port_current;
  return key_return;
	 
}





