/******************** (C) COPYRIGHT 2007 STMicroelectronics ********************
* File Name          : MC_qmath.h
* Author             : IMS Systems Lab 
* Date First Issued  : 21/11/07
* Description        : Contains two q1.15/q1.31 math routines:
*                      q1.15 x q1.15 and q1.31 / q1.15
********************************************************************************
* History:
* 21/11/07 v1.0
********************************************************************************
* THE PRESENT SOFTWARE WHICH IS FOR GUIDANCE ONLY AIMS AT PROVIDING CUSTOMERS
* WITH CODING INFORMATION REGARDING THEIR PRODUCTS IN ORDER FOR THEM TO SAVE TIME.
* AS A RESULT, STMICROELECTRONICS SHALL NOT BE HELD LIABLE FOR ANY DIRECT,
* INDIRECT OR CONSEQUENTIAL DAMAGES WITH RESPECT TO ANY CLAIMS ARISING FROM THE
* CONTENT OF SUCH SOFTWARE AND/OR THE USE MADE BY CUSTOMERS OF THE CODING
* INFORMATION CONTAINED HEREIN IN CONNECTION WITH THEIR PRODUCTS.
*******************************************************************************/

/* Define to prevent recursive inclusion -------------------------------------*/
#ifndef __MC_QMATH_H
#define __MC_QMATH_H

/* Includes ------------------------------------------------------------------*/
/* Exported types ------------------------------------------------------------*/
/* Exported constants --------------------------------------------------------*/
/* Exported macro ------------------------------------------------------------*/
/* Exported functions ------------------------------------------------------- */

void mul_q15_q15_q31(s16 Op1, s16 Op2, s32 *Out);
void div_q31_q15_q15(s16 LeftOpMsb, u16 LeftOpLsb, s16 RightOp, s16 *Output);

/*******************************************************************************
* Function Name  : mul_q15_q15_q31
* Description    : This function multiplies two q1.15 variables. Its result is
*                  a q1.31 value.
* Input          : Operand 1 (factor), Operand 2 (factor)
* Output         : Op1 * Op2, q1.31 format
* Return         : none.
*******************************************************************************/

#pragma inline
void mul_q15_q15_q31(s16 Op1, s16 Op2, s32 *Out)
{
  s32 temp;
 
  temp = Op1 * Op2;
  
  if (temp==0x40000000)   /* Overflow (-1*-1) */
  {
    temp=0x7fffffff;
  }
  else
  {       
     temp = temp * 2;       /* One bit left shift to remove redondant sign bit */       
  }  
  *Out=temp;
}

/*******************************************************************************
* Function Name  : div_q31_q15_q15
* Description    : This function divides a q1.31 by a q1.15 variable. Its result 
*                  is a q1.15 value.
* Input          : Operand 1 (dividend) MSB, Operand 1 (dividend) LSB,
*                  Operand 2 (divisor)
* Output         : Op1 / Op2, q1.15 format
* Return         : none.
*******************************************************************************/

#pragma inline
void div_q31_q15_q15(s16 LeftOpMsb, u16 LeftOpLsb, s16 RightOp, s16 *Output)
{

 long aux1, aux2;
 long temp1, temp2;
 short nb_bits, i, CS, test;

//aux1 = (s32)LeftOpMsb<<16;  /* creating a long to provide*/
 
  aux1 = (s32)(LeftOpMsb*65536);  /* creating a long to provide*/
 
 
 
 aux1 += (unsigned)LeftOpLsb; /* a 32 bits dividende */

 if( RightOp==0 )
 {
   if( aux1<0 )
   {
     *Output = 0x8000;
   }
   if( aux1>=0 )
   {
     *Output = 0x7fff;
   }
 }
 else
 {
  
   
 //aux2 = (s32)RightOp<<16;    /* divisor  */
   
   aux2 = (s32)RightOp*65536;    /* divisor  */
   
   
   temp1 = aux1&0x80000000;
   temp2 = aux2&0x80000000;

   if (temp1==temp2)
   {
     CS=0;		
     test=0;
   }
   else
   {
     CS=1;	/* CS=1 for different signs */
     test=1;
   }

 //ux1 = aux1<<1 ;
   aux1 = aux1*2;
   
   aux1 += test;

   nb_bits=15;

   for (i=0; i<nb_bits; i++)
   {
     if (CS==1)
     {      
       aux1 += aux2;
     }
     else
     {      
       aux1 -= aux2;
     }

     temp1 = aux1&0x80000000;
     /*     temp2 = aux2&0x80000000;  */    /* temp2 has not been modified  */
     if ( temp1==temp2 )
     {
       CS=0;
       test=1;	// shift !CS into partial remainder
     }
     else
     {
       CS=1;
       test=0;
     }
     
     //x1 = (aux1<<1);
     
     aux1 = (aux1*2);
     aux1 += test;
   }

   *Output = (s16)aux1;
 }	
}


#endif /* __MC_QMATH_H */
/******************* (C) COPYRIGHT 2007 STMicroelectronics *****END OF FILE****/
