/******************** (C) COPYRIGHT 2007 STMicroelectronics ********************
* File Name          : MC_Display.c
* Author             : IMS Systems Lab 
* Date First Issued  : 21/11/07
* Description        : This file contains the software implementation of the
*                      display routines
********************************************************************************
* History:
* 21/11/07 v1.0
********************************************************************************
* THE PRESENT SOFTWARE WHICH IS FOR GUIDANCE ONLY AIMS AT PROVIDING CUSTOMERS
* WITH CODING INFORMATION REGARDING THEIR PRODUCTS IN ORDER FOR THEM TO SAVE TIME.
* AS A RESULT, STMICROELECTRONICS SHALL NOT BE HELD LIABLE FOR ANY DIRECT,
* INDIRECT OR CONSEQUENTIAL DAMAGES WITH RESPECT TO ANY CLAIMS ARISING FROM THE
* CONTENT OF SUCH SOFTWARE AND/OR THE USE MADE BY CUSTOMERS OF THE CODING
* INFORMATION CONTAINED HEREIN IN CONNECTION WITH THEIR PRODUCTS.
*******************************************************************************/
/* Standard include ----------------------------------------------------------*/
#include "stm32f10x_lib.h"  

/* Include of other module interface headers ---------------------------------*/
/* Local includes ------------------------------------------------------------*/

#include "stm32f10x_MClib.h"
#include "MC_Globals.h"
#include   <math.h> 

/*Global variable*/
u8 bMenu_index=STOP_MENU;
extern u32 Duty;
extern u16 wGlobal_Flags;
/* Private typedef -----------------------------------------------------------*/
/* Private define ------------------------------------------------------------*/
#define BLINKING_TIME   5  // 5 * timebase_display_5 ms
#define DISPLAYINTERVAL	500

//Variable increment and decrement
#define MIN_STEP	50
static u16 speedstep;

/* Private macro -------------------------------------------------------------*/
/* Private functions ---------------------------------------------------------*/

extern u8 StartTime;
extern vu32 hRotorFreq;
//extern static u32 Duty;

/* Private variables ---------------------------------------------------------*/
volatile static u16 hTimebase_Blinking;
extern volatile bool PID_Control;

#ifdef OBSERVER_GAIN_TUNING
extern volatile s32 wK1_LO;
extern volatile s32 wK2_LO;
extern volatile s16 hPLL_P_Gain, hPLL_I_Gain;

#endif
//u8 String[2][16];
/*Private function*/
void SignedValueTo6bitStr(u16 speed,char *str);  
extern  int abs(int x);

/*******************************************************************************
* Function Name  : Display_Welcome_Message
* Description    : Welcome message on LCD after power-up
* Input          : None
* Output         : None
* Return         : None
*******************************************************************************/
void Display_Welcome_Message(void)
{
  char *ptr = "STM32 Motor Test";
  LCD_Print(0,0, ptr);   
  ptr = "Press ON to Start";
  LCD_Print(1,0, ptr);
  DelayTimer(200);
  ptr="Rated:     rpm  ";
  LCD_Print(1,0, ptr);             
}  

/*******************************************************************************
* Function Name  : Display_LCD
* Description    : Display routine for LCD management
* Input          : None
* Output         : None
* Return         : None
*******************************************************************************/
void Display_LCD(void)
{   char *str; 
	static u8 bPrevious_menu=STOP_MENU,bCurrent_menu;
	u16 Actual_Speed=hRotorFreq;	
  	bCurrent_menu=bMenu_index;
    switch(bCurrent_menu)
		{
		 case STOP_MENU:
		 	if(bCurrent_menu!=bPrevious_menu)
		    	{ //  LCD_Print(1,0,"Rated:     rpm  " );
			  	LCD_Print(0,0,"STM32 Motor Test");
				}	
		 	SignedValueTo6bitStr(PID_Speed_InitStructure.Reference,str); 
			LCD_Print(1,6,str);	
			break;
		 case RUN_MENU:
		   	if(bCurrent_menu!=bPrevious_menu)
		    	{ //  LCD_Print(1,0,"Rated:     rpm  " );
			 	 LCD_Print(0,0,"Real :     rpm  ");
				} //StartTimer(TIMERDISPLAY,DISPLAYINTERVAL);
		   if (ReadTimer(TIMERDISPLAY) == OK) 
  			{ 
    		StartTimer(TIMERDISPLAY,DISPLAYINTERVAL);  // refresh LCD every 500ms  in runing state
		 	SignedValueTo6bitStr(Actual_Speed,str); 
			LCD_Print(0,6,str);	
			SignedValueTo6bitStr(PID_Speed_InitStructure.Reference,str); 
			LCD_Print(1,6,str);	
			}
			break;
		 case ERR_MENU: 
		 	LCD_Print(0,0,"ERR,ON Restart");
			if (ReadTimer(TIMERDISPLAY) == OK) 
  			{ 
    		StartTimer(TIMERDISPLAY,DISPLAYINTERVAL); 	
			SignedValueTo6bitStr(PID_Speed_InitStructure.Reference,str); 
			LCD_Print(1,6,str);	
			}
		 	break;
		 default: break;
		}
   bPrevious_menu=bCurrent_menu;
}   

/*******************************************************************************
* Function Name  : KEYS_process
* Description    : Process key 
* Input          : Key code
* Output         : None
* Return         : None
*******************************************************************************/
void KEYS_process(void)
{
u8 bKey;
u16 speedset;
bKey = KEYS_Read();    
speedset=  PID_Speed_InitStructure.Reference;
if(speedset<1000) speedstep=MIN_STEP;
else if(speedset<3000) speedstep=MIN_STEP*2;
else if(speedset<10000) speedstep=MIN_STEP*10;
else speedstep=MIN_STEP*20;
switch (bMenu_index)
  { 
    case STOP_MENU:
		switch(bKey)
			{case ONOFF:
			 	State=INIT;bMenu_index=RUN_MENU; 
			 	break;
			case PLUS:
				if(speedset <(MOTOR_MAX_SPEED_RPM-speedstep+1))
				PID_Speed_InitStructure.Reference += speedstep; 
			    break;
			case MINUS:
				if (speedset > (MIN_STEP+1))
				PID_Speed_InitStructure.Reference -= speedstep; 
			    break;
			 default: break;
			}
	break;
	case RUN_MENU:
		switch(bKey)
			{case ONOFF:  hRotorFreq=0;
			 	State=STOP;bMenu_index=STOP_MENU; 
			 	break;
			case PLUS:
				if(speedset <(MOTOR_MAX_SPEED_RPM-speedstep+1))
				PID_Speed_InitStructure.Reference += speedstep; 
			    break;
			case MINUS:
				if (speedset > (MIN_STEP+1))
				PID_Speed_InitStructure.Reference -= speedstep; 
			    break;
			 default: break;
			}
	break;
	case ERR_MENU:
			switch(bKey)
			{case ONOFF:
			 	State=INIT;bMenu_index=RUN_MENU;StartTime=0; 
			 	break;
			case PLUS:
				if(speedset <(MOTOR_MAX_SPEED_RPM-speedstep+1))
				PID_Speed_InitStructure.Reference += speedstep; 
			    break;
			case MINUS:
				if (speedset > (MIN_STEP+1))
				PID_Speed_InitStructure.Reference -= speedstep; 
			    break;
			 default: break;
			}
	break;
	 default: break;  	
  }
}    
/*******************************************************************************
* Function Name  : SignedValueTo6bitStr	 (also can use the math library function)
* Description    : change the speed value to a signed No bit and store in str
* Input          : Line, starting point in LCD dysplay matrix, 5 digit signed
*                  number 
* Output         : None
* Return         : None		    
*******************************************************************************/
 
void SignedValueTo6bitStr(u16 speed,char *str)
{ 	//5 bit NO,1 bit signed
	u8 i,temp;
	u8 top=0;
	//u16 value16=abs(speed);
	u16 value16=speed;
	if(!value16) {str[0]='0';top=1;}
	else{
	for(i=0;i<5;i++)
	{
	 str[i]=value16%10;
	 value16/=10;
	}
	for(i=4;i>=0;i--) if(str[i]) {top=i;break;}
	top++;
	//if(speed<0) str[top]='-';
	for(i=0;i<top;i++) str[i]+=0x30;//change to ASCII index
  	for(i=0;i<top/2;i++) {temp=str[i];str[i]=str[top-i-1];str[top-i-1]=temp;}	
		}
	for(i=top;i<5;i++)str[i]=' ';
	str[5]='\0';
}    
  
/******************* (C) COPYRIGHT 2007 STMicroelectronics *****END OF FILE****/
