/******************** (C) COPYRIGHT 2007 STMicroelectronics ********************
* File Name          : MC_MotorControl_Layer.c
* Author             : IMS Systems Lab  
* Date First Issued  : 21/11/07
* Description        : This file contains the function implementing the motor 
*                      control layer 
********************************************************************************
* History:
* 21/11/07 v1.0
********************************************************************************
* THE PRESENT SOFTWARE WHICH IS FOR GUIDANCE ONLY AIMS AT PROVIDING CUSTOMERS
* WITH CODING INFORMATION REGARDING THEIR PRODUCTS IN ORDER FOR THEM TO SAVE TIME.
* AS A RESULT, STMICROELECTRONICS SHALL NOT BE HELD LIABLE FOR ANY DIRECT,
* INDIRECT OR CONSEQUENTIAL DAMAGES WITH RESPECT TO ANY CLAIMS ARISING FROM THE
* CONTENT OF SUCH SOFTWARE AND/OR THE USE MADE BY CUSTOMERS OF THE CODING
* INFORMATION CONTAINED HEREIN IN CONNECTION WITH THEIR PRODUCTS.
*******************************************************************************/

/* Includes ------------------------------------------------------------------*/
#include "stm32f10x_lib.h"
#include "stm32f10x_MClib.h"
#include "stm32f10x_type.h"
#include "MC_Globals.h"
#include "timer.h"

/* Private typedef -----------------------------------------------------------*/
/* Private define ------------------------------------------------------------*/
#define BRK_GPIO GPIOB
#define BRK_PIN GPIO_Pin_12

#define FAULT_STATE_MIN_PERMANENCY 600 //0.5msec unit

#define BUS_AV_ARRAY_SIZE  (u8)32  //number of averaged acquisitions
#define T_AV_ARRAY_SIZE  (u16)2048  //number of averaged acquisitions

#define BUSV_CONVERSION (u16) 415 
#define TEMP_CONVERSION (u8)  195

#define VOLT_ARRAY_INIT (u16)(UNDERVOLTAGE_THRESHOLD+ OVERVOLTAGE_THRESHOLD)/2
#define TEMP_ARRAY_INIT (u16)0

//#define BRAKE_GPIO_PORT       GPIOD
//#define BRAKE_GPIO_PIN        GPIO_Pin_13

#define NTC_THRESHOLD (u16) ((32768*(NTC_THRESHOLD_C - 14))/TEMP_CONVERSION)
#define NTC_HYSTERIS  (u16) ((32768*(NTC_THRESHOLD_C - NTC_HYSTERIS_C - 14))\
                                                               /TEMP_CONVERSION)




/* Private macro -------------------------------------------------------------*/
/* Private functions ---------------------------------------------------------*/
/* Private variables ---------------------------------------------------------*/

extern u16 wGlobal_Flags;
//extern u8  Last_HallState;
//extern u8  Curr_HallState;  
/*******************************************************************************
* Function Name  : MCL_Init
* Description    : This function implements the motor control initialization to 
*                  be performed at each motor start-up 
* Input          : None
* Output         : None
* Return         : None
*******************************************************************************/
void MCL_Init(void)
{  

   switch( ReadHallState())
   {case STATE_1:
   TIM1->CCER &= 0x2AAA;  // Clear CC1 to CC3

   //TIM1->CCER |= (UH|WL); //Enable UH and WL 
    TIM1->CCER |= (UH|VL);

   break;

  case STATE_5:
   TIM1->CCER &= 0x2AAA;  // Clear CC1 to CC3

   //TIM1->CCER |= (UH|VL); //Enable UH and VL
    TIM1->CCER |= (WH|VL); 

   break; 
   
   case STATE_4:
   TIM1->CCER &= 0x2AAA;  // Clear CC1 to CC3

   //TIM1->CCER |= (WH|VL); //Enable WH and VL 
   TIM1->CCER |= (WH|UL);
   break;

	case STATE_6:
   TIM1->CCER &= 0x2AAA;  // Clear CC1 to CC3

   //TIM1->CCER |= (WH|UL); //Enable WH and UL 
   TIM1->CCER |= (VH|UL);

   break;

     case STATE_2:
   TIM1->CCER &= 0x2AAA;  // Clear CC1 to CC3

   //TIM1->CCER |= (VH|UL); //Enable VH and UL
   TIM1->CCER |= (VH|WL); 

   break;

   case STATE_3:
   TIM1->CCER &= 0x2AAA;  // Clear CC1 to CC3

   //TIM1->CCER |= (VH|WL); //Enable VH and WL 
   TIM1->CCER |= (UH|WL);

   break;

   default:

   TIM1->CCER &= 0x2AAA;  // Clear CC1 to CC3
   
   break;

   }
    TIM1_CtrlPWMOutputs(ENABLE);
	DelayTimer(4);
 	TIM_Cmd(TIM3, ENABLE);
   	TIM_ITConfig(TIM3, TIM_IT_Trigger, ENABLE);
    HALL_InitHallMeasure();

    /* Set TIMx_BDTR->MOD bit,Main PWM Output Enable*/

	//delay 4ms for parameter settup

}




/*******************************************************************************
* Function Name  : MCL_SetFault() 
* Description    : This function manage faults occurences
* Input          : Fault type
* Output         : None
* Return         : None
*******************************************************************************/
void MCL_SetFault(u16 hFault_type)
{
  /* Main PWM Output Enable */
  TIM1_CtrlPWMOutputs(DISABLE);
  wGlobal_Flags = hFault_type;
  State = FAULT;
  bMenu_index = ERR_MENU;  
}

