/******************** (C) COPYRIGHT 2007 STMicroelectronics ********************
* File Name          : MC_PID_regulators.c
* Author             : IMS Systems Lab 
* Date First Issued  : 21/11/07
* Description        : This file contains the software implementation for the
                       PI(D) regulators.
********************************************************************************
* History:
* 21/11/07 v1.0
********************************************************************************
* THE PRESENT SOFTWARE WHICH IS FOR GUIDANCE ONLY AIMS AT PROVIDING CUSTOMERS
* WITH CODING INFORMATION REGARDING THEIR PRODUCTS IN ORDER FOR THEM TO SAVE TIME.
* AS A RESULT, STMICROELECTRONICS SHALL NOT BE HELD LIABLE FOR ANY DIRECT,
* INDIRECT OR CONSEQUENTIAL DAMAGES WITH RESPECT TO ANY CLAIMS ARISING FROM THE
* CONTENT OF SUCH SOFTWARE AND/OR THE USE MADE BY CUSTOMERS OF THE CODING
* INFORMATION CONTAINED HEREIN IN CONNECTION WITH THEIR PRODUCTS.
*******************************************************************************/

/* Standard include ----------------------------------------------------------*/

#include "stm32f10x_lib.h"
#include "stm32f10x_MClib.h"
#include "stm32f10x_type.h"
#include "MC_Globals.h"


extern volatile bool HallTimeOut;
extern u8 bPresent_Visualization;
extern volatile bool PID_Control;

s32 speed_integ = 0;
s32 speed_diff = 0;

//PWM Duty Cycle initization to 0
u16 Duty1 = 0;
u16 Duty2 = 0;
u16 Duty = 0;

s32 speed_integral = 0;
s32 speed_proportional = 0;
s32 speed_error = 0;
s32 speed_error_1 = 0;
s32 increament = 0;


 /*******************************************************************************
* Function Name  : PID_Speed_Coefficients_update
* Description    : Update Kp, Ki & Kd coefficients of speed regulation loop 
                   according to motor speed. See "_MC_CONTROL_PARAM_H" for parameters 
                   setting
* Input          : s16 
                   Mechanical motor speed with 0.1 Hz resolution 
                   eg: 10Hz <-> (s16)100
* Output         : None
* Return         : None
*******************************************************************************/
void PID_Speed_Coefficients_update(u32 PID_speed)
{

 if ( State == START )
 {
// if (HallTimeOut == FALSE)
// {
	 speed_error = PID_Speed_InitStructure.Reference - PID_speed;
	 if (PID_Control == FALSE) 
     { 	//the PID parameter is just for Motor FB_824-B-CF
	  {if (PID_Speed_InitStructure.Reference <=8000)
	   { //Enlargetime= 40,real kp=0.5 
		PID_Speed_InitStructure.Kp_Gain = 8;
	   PID_Speed_InitStructure.Ki_Gain = 1;
	   PID_Speed_InitStructure.Kd_Gain = 0;
		}
		else if (PID_Speed_InitStructure.Reference<=12000)
		{
		PID_Speed_InitStructure.Kp_Gain = 10;
	   PID_Speed_InitStructure.Ki_Gain = 1;
	   PID_Speed_InitStructure.Kd_Gain = 0;
		}
		else  if (PID_Speed_InitStructure.Reference<=21000) 
		{
		PID_Speed_InitStructure.Kp_Gain = 10;
	   PID_Speed_InitStructure.Ki_Gain = 2;
	   PID_Speed_InitStructure.Kd_Gain = 0;
	    }
	   	else  
		{
		PID_Speed_InitStructure.Kp_Gain = 15;
	   PID_Speed_InitStructure.Ki_Gain = 3;
	   PID_Speed_InitStructure.Kd_Gain = 0;
	    }
	   }
	   }
  speed_proportional = PID_Speed_InitStructure.Kp_Gain*speed_error;

  speed_integral = speed_integral + speed_error;

  speed_diff = PID_Speed_InitStructure.Kd_Gain * (speed_error - speed_error_1);

  if(speed_integral >  MOTOR_MAX_SPEED_RPM) speed_integral =  MOTOR_MAX_SPEED_RPM;
  if(speed_integral < -MOTOR_MAX_SPEED_RPM) speed_integral = -MOTOR_MAX_SPEED_RPM;

  speed_integ = PID_Speed_InitStructure.Ki_Gain*speed_integral;


  increament = speed_proportional+speed_integ+speed_diff;

 //PID_DIV=(FULL PWM PERIOD/RMP_MAX_SPEED)*Enlargetime=(1250/1800)*64=14
  increament = increament>>6;  //2^6=64
  


      if(increament >= 1250)
	  Duty = 1250;
    else
    {
      if(increament <= 0)
	  //Duty = 0x100;
	  Duty=0x50;
      else Duty = (u16)(increament);
	  }
	  Duty2=Duty;
  
    if((Duty2-Duty1)>=40)
    {Duty=Duty1+40;}
  
    if((Duty1-Duty2)>=40)
    {Duty=Duty1- 40;}
  
    if(Duty<= 0)
    { Duty=0x50;}  
  
    if(Duty >=1250)
    {Duty = 1250;}  
    
    Duty1=Duty;

	TIM1->CCR1 = Duty;
	TIM1->CCR2 = Duty;
	TIM1->CCR3 = Duty;
	
	}
  	

//else 
//{
//  HallTimeOut = FALSE;
//  }
// }
}
void Clear_speed_error(void)
{
  speed_error = 0;
  speed_integral = 0;
  speed_integ = 0;
  Duty1 = 0;
  Duty2 = 0;
  Duty = 0;
  increament=0;

  }

/*******************************************************************************
* Function Name  : PID_Init
* Description    : Initialize PID coefficients for torque, flux and speed loop: 
                   Kp_Gain: proportional coeffcient 
                   Ki_Gain: integral coeffcient 
                   Kd_Gain: differential coeffcient 
* Input          : Pointer 1 to Torque PI structure,  
                   Pointer 2 to Flux PI structure,  
                   Pointer 3 to Speed PI structure  
* Output         : None
* Return         : None
*******************************************************************************/
void PID_Init (PID_SpeedTYPEDEF *PID_Speed)
 {
  speed_error = 0;   // reset last error value 

  
  PID_Speed->Reference = PID_SPEED_REFERENCE_RPM;

 // PID_Speed->Kp_Gain = PID_SPEED_KP_DEFAULT;
 // PID_Speed->Ki_Gain = PID_SPEED_KI_DEFAULT;

#ifdef SPEED_DIFFERENTIAL_TERM_ENABLED
  PID_Speed->Kd_Gain = PID_SPEED_KD_DEFAULT;
#endif
  //Lower Limit for Output limitation
  PID_Speed->Lower_Limit_Output= -NOMINAL_CURRENT;  
  //Upper Limit for Output limitation
  PID_Speed->Upper_Limit_Output= NOMINAL_CURRENT;     
  PID_Speed->Max_PID_Output = FALSE;
  PID_Speed->Min_PID_Output = FALSE;
  PID_Control = FALSE;

}

/******************** (C) COPYRIGHT 2007 STMicroelectronics *******************/
