/******************** (C) COPYRIGHT 2007 STMicroelectronics ********************
* File Name          : stm32f10x_hall.c
* Author             : IMS Systems Lab 
* Date First Issued  : 21/11/07
* Description        : Module handling speed feedback provided by three Hall 
*                      sensors
********************************************************************************
* History:
* 21/11/07 v1.0
********************************************************************************
* THE PRESENT SOFTWARE WHICH IS FOR GUIDANCE ONLY AIMS AT PROVIDING CUSTOMERS
* WITH CODING INFORMATION REGARDING THEIR PRODUCTS IN ORDER FOR THEM TO SAVE TIME.
* AS A RESULT, STMICROELECTRONICS SHALL NOT BE HELD LIABLE FOR ANY DIRECT,
* INDIRECT OR CONSEQUENTIAL DAMAGES WITH RESPECT TO ANY CLAIMS ARISING FROM THE
* CONTENT OF SUCH SOFTWARE AND/OR THE USE MADE BY CUSTOMERS OF THE CODING
* INFORMATION CONTAINED HEREIN IN CONNECTION WITH THEIR PRODUCTS.
*******************************************************************************/

/* Includes ------------------------------------------------------------------*/
#include "stm32f10x_lib.h"
#include "stm32f10x_hall.h"
#include "MC_hall_prm.h"
#include "MC_Globals.h"
#include "stm32f10x_MClib.h"
#include "stm32f10x_it.h"
#include "stm32f10x_type.h"
/* Private define ------------------------------------------------------------*/
#define HALL_MAX_SPEED_FDBK (u16)(HALL_MAX_SPEED_FDBK_RPM/6)
#define HALL_MIN_SPEED_FDBK (u16)(HALL_MIN_SPEED_FDBK_RPM/6)
#define LOW_RES_THRESHOLD   ((u16)0x5500u)// If capture below, ck prsc decreases

#define PSEUDO_FREQ_CONV    ((u32)(ROTOR_SPEED_FACTOR / (SAMPLING_FREQ * 10)) * 0x10000uL)
#define SPEED_OVERFLOW      ((u32)(ROTOR_SPEED_FACTOR / HALL_MAX_SPEED_FDBK))
#define MAX_PERIOD          ((u32)(ROTOR_SPEED_FACTOR / HALL_MIN_SPEED_FDBK))
#define HALL_COUNTER_RESET  ((u16) 0)
#define S16_PHASE_SHIFT     (s16)(HALL_PHASE_SHIFT * 65536/360)
#define S16_120_PHASE_SHIFT (s16)(65536/3)
#define S16_60_PHASE_SHIFT  (s16)(65536/6)



#define NEGATIVE          (s8)-1
#define POSITIVE          (s8)1
#define NEGATIVE_SWAP     (s8)-2
#define POSITIVE_SWAP     (s8)2
#define ERROR             (s8)127

#define GPIO_MSK (u8)0x07
#define ICx_FILTER (u8) 0x08 // 6 <-> 670nsec 

#define TIMx_PRE_EMPTION_PRIORITY 2
#define TIMx_SUB_PRIORITY 0

/* if (HALL_SENSORS_PLACEMENT == DEGREES_120)
The sequence of the states is {STATE_5,STATE_1,STATE_3,STATE_2,STATE_6,STATE_4}
else if (HALL_SENSORS_PLACEMENT == DEGREES_60)
the sequence is {STATE_1,STATE_3,STATE_7,STATE_6,STATE_4,STATE_0}*/

// Here is practically assigned the timer for Hall handling
#if defined(TIMER2_HANDLES_HALL)
    #define HALL_TIMER TIM2
#elif defined(TIMER3_HANDLES_HALL)
    #define HALL_TIMER TIM3
#else // TIMER4_HANDLES_HALL
    #define HALL_TIMER TIM4
#endif

//static u32 new_period;
extern volatile bool HallTimeOut;
//extern volatile bool FALLING_RISING;
/* Private macro -------------------------------------------------------------*/
/* Private typedef -----------------------------------------------------------*/
//typedef struct {
//	u16 hCapture;
//	u16 hPrscReg;
 //       s8 bDirection;
//	} SpeedMeas_s;

//typedef struct {
  //      u32 wPeriod;
    //    s8 bDirection;
      //  } PeriodMeas_s;
/* Private variables ---------------------------------------------------------*/

//volatile SpeedMeas_s SensorPeriod[HALL_SPEED_FIFO_SIZE];// Holding the last captures
//vu8 bSpeedFIFO_Index;   // Index of above array
vu8 bGP1_OVF_Counter;   // Count overflows if prescaler is too low
//vu16 hCaptCounter;      // Counts the number of captures interrupts
//volatile PeriodMeas_s PeriodMeas;

//volatile bool RatioDec;
//volatile bool RatioInc;
volatile bool DoRollingAverage;
volatile bool InitRollingAverage;

//static s16 hElectrical_Angle; 
//u32 hRotorFreq = 0;
//u32 hRotorFreq1 = 0;

#if (defined HALL_SENSORS || defined VIEW_HALL_FEEDBACK)
//static s8 bSpeed;
#endif
/* Private function prototypes -----------------------------------------------*/
//PeriodMeas_s GetLastHallPeriod(void);
//PeriodMeas_s GetAvrgHallPeriod(void);
//void HALL_StartHallFiltering(void);
//u16  HALL_GetCaptCounter(void);
//void HALL_ClrCaptCounter(void);

u8  ReadHallState(void); 
/*******************************************************************************
* Function Name  : Hall_HallTimerInit
* Description    : Initializes the timer handling Hall sensors feedback
* Input          : None
* Output         : None
* Return         : None
*******************************************************************************/
void HALL_HallTimerInit(void)
{

  TIM_TimeBaseInitTypeDef TIM_HALLTimeBaseInitStructure;
  TIM_ICInitTypeDef       TIM_HALLICInitStructure;
//  NVIC_InitTypeDef        NVIC_InitHALLStructure;
  GPIO_InitTypeDef        GPIO_InitStructure;
  
	/*Enable TIM2,TIM3 clock*/
    RCC_APB1PeriphClockCmd(RCC_APB1Periph_TIM2, ENABLE);
	RCC_APB1PeriphClockCmd(RCC_APB1Periph_TIM3, ENABLE);
    /* Enable GPIOA, clock */
    //RCC_APB2PeriphClockCmd(RCC_APB2Periph_GPIOA, ENABLE);

    GPIO_StructInit(&GPIO_InitStructure);
    /* Configure PA.00,01 ,02 as Hall sensors input */
    GPIO_InitStructure.GPIO_Pin = GPIO_Pin_0 | GPIO_Pin_1 | GPIO_Pin_2;
    GPIO_InitStructure.GPIO_Mode = GPIO_Mode_IN_FLOATING;
    GPIO_Init(GPIOA, &GPIO_InitStructure);

    /*Hall-Timer TIM2 config*/  
    // Timer configuration in Clear on capture mode
    TIM_DeInit(HALL_TIMER);
    TIM_TimeBaseStructInit(&TIM_HALLTimeBaseInitStructure);
    // Set full 16-bit working range
    TIM_HALLTimeBaseInitStructure.TIM_Period = U16_MAX;
    TIM_HALLTimeBaseInitStructure.TIM_ClockDivision = TIM_CKD_DIV1;
    TIM_TimeBaseInit(HALL_TIMER,&TIM_HALLTimeBaseInitStructure);
    
    TIM_ICStructInit(&TIM_HALLICInitStructure);
    TIM_HALLICInitStructure.TIM_ICPolarity = TIM_ICPolarity_Rising;
    TIM_HALLICInitStructure.TIM_ICFilter = ICx_FILTER;
    
    TIM_ICInit(HALL_TIMER,&TIM_HALLICInitStructure);
    
    // Force the HALL_TIMER prescaler with immediate access (no need of an update event) 
    TIM_PrescalerConfig(HALL_TIMER, (u16) HALL_MAX_RATIO, 
                       TIM_PSCReloadMode_Immediate);
    TIM_InternalClockConfig(HALL_TIMER);
    
    //Enables the XOR of channel 1, channel2 and channel3
    TIM_SelectHallSensor(HALL_TIMER, ENABLE);
    //select TI1FP1 as the trigger sourse
    TIM_SelectInputTrigger(HALL_TIMER, TIM_TS_TI1FP1);
    TIM_SelectSlaveMode(HALL_TIMER,TIM_SlaveMode_Reset);
   
    // Source of Update event is only counter overflow/underflow
    TIM_UpdateRequestConfig(HALL_TIMER, TIM_UpdateSource_Regular);
    																
    // Clear the TIM2's pending flags
    TIM_ClearFlag(HALL_TIMER, TIM_FLAG_Update + TIM_FLAG_CC1 + TIM_FLAG_CC2 + \
                  TIM_FLAG_CC3 + TIM_FLAG_CC4 + TIM_FLAG_Trigger + TIM_FLAG_CC1OF + \
                  TIM_FLAG_CC2OF + TIM_FLAG_CC3OF + TIM_FLAG_CC4OF);

    // Selected input capture and Update (overflow) events generate interrupt
	// Enables or disables the TIMx interrupts.
    TIM_ITConfig(HALL_TIMER, TIM_IT_CC1, ENABLE);
    TIM_ITConfig(HALL_TIMER, TIM_IT_Update, ENABLE);

    TIM_SetCounter(HALL_TIMER, HALL_COUNTER_RESET);
//	TIM_Cmd(HALL_TIMER, ENABLE);

  /*Timer3 Interrupt Config,here TIM_HALLTimeBaseInitStructure no related with HALLTIMER*/
  /*couter up generate overflow even update time=1500*1000/(72M/2)=41.6ms*/
  /*unable slave_mode,prescaller=ck_int*/
  	TIM_DeInit(TIM3);
	TIM_TimeBaseStructInit(&TIM_HALLTimeBaseInitStructure);
    TIM_HALLTimeBaseInitStructure.TIM_Period = 1500u;
    TIM_HALLTimeBaseInitStructure.TIM_ClockDivision = TIM_CKD_DIV2;
    TIM_TimeBaseInit(TIM3,&TIM_HALLTimeBaseInitStructure);
	TIM_PrescalerConfig(TIM3, (u16) HALL_MAX_RATIO, TIM_PSCReloadMode_Immediate);
    TIM_InternalClockConfig(TIM3);	//Disable slave mode,use Internalclock
	
	 TIM_ClearFlag(TIM3, TIM_FLAG_Update + TIM_FLAG_CC1 + TIM_FLAG_CC2 + \
                  TIM_FLAG_CC3 + TIM_FLAG_CC4 + TIM_FLAG_Trigger + TIM_FLAG_CC1OF + \
                  TIM_FLAG_CC2OF + TIM_FLAG_CC3OF + TIM_FLAG_CC4OF);

	TIM_ITConfig(TIM3, TIM_IT_Trigger, DISABLE);
    TIM_ITConfig(TIM3, TIM_IT_Update, ENABLE);

	TIM_SetCounter(TIM3, HALL_COUNTER_RESET);
    TIM_Cmd(TIM3, DISABLE);
       
}


/*******************************************************************************
* ROUTINE Name : HALL_InitHallMeasure
*
* Description : Clear software FIFO where are "pushed" latest speed information
*           	This function must be called before starting the motor to initialize
*	    		the speed measurement process.
*
* Input       : None
* Output      : None
* Return      : None
* Note        : First measurements following this function call will be done
*               without filtering (no rolling average).
*******************************************************************************/
void HALL_InitHallMeasure( void )
{
   // Mask interrupts to insure a clean intialization

   TIM_ITConfig(HALL_TIMER, TIM_IT_CC1, DISABLE);
    
//   RatioDec = FALSE;
//  RatioInc = FALSE;
 	DoRollingAverage = FALSE;
 	InitRollingAverage = FALSE;
//   HallTimeOut = FALSE;

  // hCaptCounter = 0;
   bGP1_OVF_Counter = 0;
   // Re-initialize partly the timer
   HALL_TIMER->PSC = HALL_MAX_RATIO;
 //restart the TIM2 counter to generate IT
   TIM2->CCR1 = 0;
   TIM_Cmd(HALL_TIMER, DISABLE);
     
   TIM_SetCounter(HALL_TIMER, HALL_COUNTER_RESET);
   
   TIM_Cmd(HALL_TIMER, ENABLE);

   TIM_ITConfig(HALL_TIMER, TIM_IT_CC1, ENABLE);

}

/*******************************************************************************
* ROUTINE Name : HALL_ReadHallState
*
* Description : Read the GPIO Input used for Hall sensor IC and return the state  
* Input       : None
* Output      : None
* Return      : STATE_X
*	
*******************************************************************************/

u8 ReadHallState(void)
{
  u8 ReadValue;
  //u8 temp;
#if defined(TIMER2_HANDLES_HALL) 
  NVIC_SETPRIMASK(); 
  ReadValue = (u8)(GPIO_ReadInputData(GPIOA))& GPIO_MSK;
  NVIC_RESETPRIMASK();
  //temp = temp>>1;
 // ReadValue = temp & GPIO_MSK;
  
#elif defined(TIMER3_HANDLES_HALL)
  
  ReadValue = GPIO_ReadInputDataBit(GPIOB, GPIO_Pin_0)<<2;
  ReadValue |= GPIO_ReadInputDataBit(GPIOA, GPIO_Pin_6)<<1;
  ReadValue |= GPIO_ReadInputDataBit(GPIOA, GPIO_Pin_7);

#elif defined(TIMER4_HANDLES_HALL)
  ReadValue = ((u8)(GPIO_ReadInputData(GPIOA))>>6) & GPIO_MSK;
#endif
  
  return(ReadValue);
}










/*******************************************************************************
* ROUTINE Name : HALL_ClrTimeOut
*
* Description     : Clears the flag indicating that that informations are lost,
*                   or speed is decreasing sharply.
* Input           : None
* Output          : Clear HallTimeOut
* Return          : None
*******************************************************************************/
void HALL_ClrTimeOut(void)
{
   HallTimeOut = FALSE;
}


/******************* (C) COPYRIGHT 2007 STMicroelectronics *****END OF FILE****/
