/******************** (C) COPYRIGHT 2007 STMicroelectronics ********************
* File Name          : stm32f10x_it.c
* Author             : IMS Systems Lab
* Date First Issued  : 21/11/07
* Description        : Main Interrupt Service Routines.
*                      This file can be used to describe all the exceptions 
*                      subroutines that may occur within user application.
*                      When an interrupt happens, the software will branch 
*                      automatically to the corresponding routine.
*                      The following routines are all empty, user can write code 
*                      for exceptions handlers and peripherals IRQ interrupts.
********************************************************************************
* History:
* 21/11/07 v1.0
********************************************************************************
* THE PRESENT SOFTWARE WHICH IS FOR GUIDANCE ONLY AIMS AT PROVIDING CUSTOMERS
* WITH CODING INFORMATION REGARDING THEIR PRODUCTS IN ORDER FOR THEM TO SAVE TIME.
* AS A RESULT, STMICROELECTRONICS SHALL NOT BE HELD LIABLE FOR ANY DIRECT,
* INDIRECT OR CONSEQUENTIAL DAMAGES WITH RESPECT TO ANY CLAIMS ARISING FROM THE
* CONTENT OF SUCH SOFTWARE AND/OR THE USE MADE BY CUSTOMERS OF THE CODING
* INFORMATION CONTAINED HEREIN IN CONNECTION WITH THEIR PRODUCTS.
*******************************************************************************/

/* Includes ------------------------------------------------------------------*/
#include "stm32f10x_it.h"
#include "timer.h"
#include "stm32f10x_MClib.h"
#include "MC_Globals.h"

/* Private typedef -----------------------------------------------------------*/
/* Private define ------------------------------------------------------------*/
#define BRAKE_HYSTERESIS (u16)((OVERVOLTAGE_THRESHOLD/16)*15)
#define	ROTOR_SPEED_FACTOR  ((u32)((CKTIM*10)))

volatile bool HallTimeOut;

vu32 hRotorFreq = 0;
u16 PID_number = 100;
volatile bool time_set = TRUE;
u32 Motor_data; 
int motor_inter_time = 20;
u8 Clock1s;

extern volatile SystStatus_t State;
extern u16 wGlobal_Flags;
extern vu8 bGP1_OVF_Counter;
extern u8 bMenu_index;
extern volatile u8 StartTime;
//u8  Last_HallState;
//u8  Curr_HallState;
/* Private macro -------------------------------------------------------------*/
/* Private variables ---------------------------------------------------------*/
/* Private function prototypes -----------------------------------------------*/
/* Private functions ---------------------------------------------------------*/




/*******************************************************************************
* Function Name  : SysTick_Handler
* Description    :  SysTick interrupt happens every 1 ms,as systicks
* Input          : None
* Output         : None
* Return         : None
*******************************************************************************/
void SysTick_Handler (void) 
{
//  static u32 ticks;
  u8	i;
  /*TimerTable management*/
  /*use the overflag principle,interval is the setting 1ms counte*/
  for(i=0;i<TIMERAMOUNT;i++)
  {
      
      if(TimerTable[i].runningstate==SYSON)
      {
          if(TimerTable[i].overflag==SYSOFF)
          {
              if(TimerTable[i].interval>=1)
	           TimerTable[i].interval--;
	          else
	          {
		          TimerTable[i].overflag=SYSON;
		          TimerTable[i].interval=0;
	          }
          }
      }
  }



}

/*******************************************************************************
* Function Name  : NMIException
* Description    : This function handles NMI exception.
* Input          : None
* Output         : None
* Return         : None
*******************************************************************************/
void NMIException(void)
{
}

/*******************************************************************************
* Function Name  : HardFaultException
* Description    : This function handles Hard Fault exception.
* Input          : None
* Output         : None
* Return         : None
*******************************************************************************/
void HardFaultException(void)
{
  /* Go to infinite loop when Hard Fault exception occurs */
  while (1)
  {
  }
}

/*******************************************************************************
* Function Name  : MemManageException
* Description    : This function handles Memory Manage exception.
* Input          : None
* Output         : None
* Return         : None
*******************************************************************************/
void MemManageException(void)
{
  /* Go to infinite loop when Memory Manage exception occurs */
  while (1)
  {
  }
}

/*******************************************************************************
* Function Name  : BusFaultException
* Description    : This function handles Bus Fault exception.
* Input          : None
* Output         : None
* Return         : None
*******************************************************************************/
void BusFaultException(void)
{  
  /* Go to infinite loop when Bus Fault exception occurs */
  while (1)
  {
  }
}

/*******************************************************************************
* Function Name  : UsageFaultException
* Description    : This function handles Usage Fault exception.
* Input          : None
* Output         : None
* Return         : None
*******************************************************************************/
void UsageFaultException(void)
{
  /* Go to infinite loop when Bus Fault exception occurs */
  while (1)
  {
  }
}

/*******************************************************************************
* Function Name  : DebugMonitor
* Description    : This function handles Debug Monitor exception.
* Input          : None
* Output         : None
* Return         : None
*******************************************************************************/
void DebugMonitor(void)
{
}

/*******************************************************************************
* Function Name  : SVCHandler
* Description    : This function handles SVCall exception.
* Input          : None
* Output         : None
* Return         : None
*******************************************************************************/
void SVCHandler(void)
{
}

/*******************************************************************************
* Function Name  : PendSVC
* Description    : This function handles PendSVC exception.
* Input          : None
* Output         : None
* Return         : None
*******************************************************************************/
void PendSVC(void)
{
}

/*******************************************************************************
* Function Name  : WWDG_IRQHandler
* Description    : This function handles WWDG interrupt request.
* Input          : None
* Output         : None
* Return         : None
*******************************************************************************/
void WWDG_IRQHandler(void)
{
}

/*******************************************************************************
* Function Name  : PVD_IRQHandler
* Description    : This function handles PVD interrupt request.
* Input          : None
* Output         : None
* Return         : None
*******************************************************************************/
void PVD_IRQHandler(void)
{
 EXTI_ClearITPendingBit(EXTI_Line16);
 	  TIM1_CtrlPWMOutputs(DISABLE); 
	  TIM_Cmd(TIM3, DISABLE);
	  TIM_Cmd(TIM2, DISABLE);
	  State=FAULT; 
}

/*******************************************************************************
* Function Name  : TAMPER_IRQHandler
* Description    : This function handles Tamper interrupt request. 
* Input          : None
* Output         : None
* Return         : None
*******************************************************************************/
void TAMPER_IRQHandler(void)
{
}

/*******************************************************************************
* Function Name  : RTC_IRQHandler
* Description    : This function handles RTC global interrupt request.
* Input          : None
* Output         : None
* Return         : None
*******************************************************************************/
void RTC_IRQHandler(void)
{
}

/*******************************************************************************
* Function Name  : FLASH_IRQHandler
* Description    : This function handles Flash interrupt request.
* Input          : None
* Output         : None
* Return         : None
*******************************************************************************/
void FLASH_IRQHandler(void)
{
}

/*******************************************************************************
* Function Name  : RCC_IRQHandler
* Description    : This function handles RCC interrupt request. 
* Input          : None
* Output         : None
* Return         : None
*******************************************************************************/
void RCC_IRQHandler(void)
{
}

/*******************************************************************************
* Function Name  : EXTI0_IRQHandler
* Description    : This function handles External interrupt Line 0 request.
* Input          : None
* Output         : None
* Return         : None
*******************************************************************************/
void EXTI0_IRQHandler(void)
{

}

/*******************************************************************************
* Function Name  : EXTI1_IRQHandler
* Description    : This function handles External interrupt Line 1 request.
* Input          : None
* Output         : None
* Return         : None
*******************************************************************************/
void EXTI1_IRQHandler(void)
{
}

/*******************************************************************************
* Function Name  : EXTI2_IRQHandler
* Description    : This function handles External interrupt Line 2 request.
* Input          : None
* Output         : None
* Return         : None
*******************************************************************************/
void EXTI2_IRQHandler(void)
{
}

/*******************************************************************************
* Function Name  : EXTI3_IRQHandler
* Description    : This function handles External interrupt Line 3 request.
* Input          : None
* Output         : None
* Return         : None
*******************************************************************************/
void EXTI3_IRQHandler(void)
{
}

/*******************************************************************************
* Function Name  : EXTI4_IRQHandler
* Description    : This function handles External interrupt Line 4 request.
* Input          : None
* Output         : None
* Return         : None
*******************************************************************************/
void EXTI4_IRQHandler(void)
{
}

/*******************************************************************************
* Function Name  : DMAChannel1_IRQHandler
* Description    : This function handles DMA Stream 1 interrupt request.
* Input          : None
* Output         : None
* Return         : None
*******************************************************************************/
void DMAChannel1_IRQHandler(void)
{
}

/*******************************************************************************
* Function Name  : DMAChannel2_IRQHandler
* Description    : This function handles DMA Stream 2 interrupt request.
* Input          : None
* Output         : None
* Return         : None
*******************************************************************************/
void DMAChannel2_IRQHandler(void)
{
}

/*******************************************************************************
* Function Name  : DMAChannel3_IRQHandler
* Description    : This function handles DMA Stream 3 interrupt request.
* Input          : None
* Output         : None
* Return         : None
*******************************************************************************/
void DMAChannel3_IRQHandler(void)
{
}

/*******************************************************************************
* Function Name  : DMAChannel4_IRQHandler
* Description    : This function handles DMA Stream 4 interrupt request.
* Input          : None
* Output         : None
* Return         : None
*******************************************************************************/
void DMAChannel4_IRQHandler(void)
{
}

/*******************************************************************************
* Function Name  : DMAChannel5_IRQHandler
* Description    : This function handles DMA Stream 5 interrupt request.
* Input          : None
* Output         : None
* Return         : None
*******************************************************************************/
void DMAChannel5_IRQHandler(void)
{
}

/*******************************************************************************
* Function Name  : DMAChannel6_IRQHandler
* Description    : This function handles DMA Stream 6 interrupt request.
* Input          : None
* Output         : None
* Return         : None
*******************************************************************************/
void DMAChannel6_IRQHandler(void)
{
}

/*******************************************************************************
* Function Name  : DMAChannel7_IRQHandler
* Description    : This function handles DMA Stream 7 interrupt request.
* Input          : None
* Output         : None
* Return         : None
*******************************************************************************/
void DMAChannel7_IRQHandler(void)
{
}

/*******************************************************************************
* Function Name  : ADC_IRQHandler
* Description    : This function handles ADC global interrupt request.
* Input          : None
* Output         : None
* Return         : None
*******************************************************************************/
void ADC_IRQHandler(void)
{
 // if(ADC_GetITStatus(ADC1, ADC_IT_JEOC) == SET)
//  {
//#ifdef DAC_FUNCTIONALITY 
//    #if (defined OBSERVER_GAIN_TUNING || defined NO_SPEED_SENSORS)
//    MCDAC_Update_Value(LO_ANGLE,(s16)(STO_Get_Electrical_Angle()));
 //   MCDAC_Update_Value(LO_I_A, STO_Get_wIalfa_est());        
//    MCDAC_Update_Value(LO_I_B, STO_Get_wIbeta_est());        
 //   MCDAC_Update_Value(LO_BEMF_A, STO_Get_wBemf_alfa_est()); 
 //   MCDAC_Update_Value(LO_BEMF_B,STO_Get_wBemf_beta_est()); 
 // #endif  
//#endif
//    MCL_Calc_BusVolt();
//    switch (State)
//    {
//        case RUN:
// THREE_SHUNT          
          // Disable EXT. ADC Triggering
//          ADC1->CR2 = ADC1->CR2 & 0xFFFF7FFF;
//#endif          
//         FOC_Model();       
 //       break;       
  
//        case START:        
//  #ifdef NO_SPEED_SENSORS
//         #ifdef VIEW_ENCODER_FEEDBACK
//         ENC_Start_Up();
//         if ( (wGlobal_Flags & FIRST_START) != FIRST_START)
 //        {
//           STO_Start_Up();
//         }           
//         #else
//         STO_Start_Up();
 //        #endif
//  #elif defined ENCODER
//         ENC_Start_Up();       
//  #elif defined HALL_SENSORS
//         State = RUN;
//  #endif       
 //       break; 
  
 //       default:
 //       break;
 //   }
//#ifdef BRAKE_RESISTOR
   // if((wGlobal_Flags & BRAKE_ON) == BRAKE_ON)
 //   {
 //     u16 aux;
  //    aux = ADC_GetInjectedConversionValue(ADC1, ADC_InjectedChannel_2);
 //     
  //    if (aux < BRAKE_HYSTERESIS)
  //    {
  //     wGlobal_Flags &= ~BRAKE_ON;
  //     MCL_Set_Brake_Off();
  //    }
  //  }
//#endif    
//#ifdef DAC_FUNCTIONALITY  
//    MCDAC_Update_Value(I_A,Stat_Curr_a_b.qI_Component1);
//    MCDAC_Update_Value(I_B,Stat_Curr_a_b.qI_Component2);
//    MCDAC_Update_Value(I_ALPHA,Stat_Curr_alfa_beta.qI_Component1);
//    MCDAC_Update_Value(I_BETA,Stat_Curr_alfa_beta.qI_Component2);
//    MCDAC_Update_Value(I_Q,Stat_Curr_q_d.qI_Component1);
 //  MCDAC_Update_Value(I_D,Stat_Curr_q_d.qI_Component2);
 //   MCDAC_Update_Value(I_Q_REF,PID_Torque_InitStructure.Reference);
 //   MCDAC_Update_Value(I_D_REF,PID_Flux_InitStructure.Reference);
 //   MCDAC_Update_Value(V_Q,Stat_Volt_q_d.qV_Component1);
 //   MCDAC_Update_Value(V_D,Stat_Volt_q_d.qV_Component2);
  //  MCDAC_Update_Value(V_ALPHA,Stat_Volt_alfa_beta.qV_Component1);
 //   MCDAC_Update_Value(V_BETA,Stat_Volt_alfa_beta.qV_Component2); 
 //   #if (defined ENCODER || defined VIEW_ENCODER_FEEDBACK)
//    MCDAC_Update_Value(SENS_ANGLE,ENC_Get_Electrical_Angle());
//    #elif (defined HALL_SENSORS)
 //   if (State != RUN)
 //   {HALL_IncElectricalAngle();}
 //   MCDAC_Update_Value(SENS_ANGLE,HALL_GetElectricalAngle());  
//    #elif (defined VIEW_HALL_FEEDBACK)
//    HALL_IncElectricalAngle();  
//    MCDAC_Update_Value(SENS_ANGLE,HALL_GetElectricalAngle());
//    #endif
//    #if ((defined OBSERVER_GAIN_TUNING) && (!defined(NO_SPEED_SENSORS)))
//    STO_Calc_Rotor_Angle(Stat_Volt_alfa_beta,Stat_Curr_alfa_beta,MCL_Get_BusVolt());    
//    #endif

//    MCDAC_Update_Output();
//#endif    
    
 //   ADC_ClearFlag(ADC1, ADC_FLAG_JEOC);
//  }
//  else 
//  {
//    if(ADC_GetITStatus(ADC1, ADC_IT_AWD) == SET)
//    {
//#ifdef BRAKE_RESISTOR
      //Analog watchdog interrupt has been generated 
//     MCL_Set_Brake_On(); 
//     wGlobal_Flags |= BRAKE_ON;
//#else
//     MCL_SetFault(OVER_VOLTAGE);
//#endif     
 //    ADC_ClearFlag(ADC1, ADC_FLAG_AWD); 
//    }    
//  }
}

/*******************************************************************************
* Function Name  : USB_HP_CAN_TX_IRQHandler
* Description    : This function handles USB High Priority or CAN TX interrupts 
*                  requests.
* Input          : None
* Output         : None
* Return         : None
*******************************************************************************/
void USB_HP_CAN_TX_IRQHandler(void)
{
}

/*******************************************************************************
* Function Name  : USB_LP_CAN_RX0_IRQHandler
* Description    : This function handles USB Low Priority or CAN RX0 interrupts 
*                  requests.
* Input          : None
* Output         : None
* Return         : None
*******************************************************************************/
void USB_LP_CAN_RX0_IRQHandler(void)
{
}

/*******************************************************************************
* Function Name  : CAN_RX1_IRQHandler
* Description    : This function handles CAN RX1 interrupt request.
* Input          : None
* Output         : None
* Return         : None
*******************************************************************************/
void CAN_RX1_IRQHandler(void)
{
}

/*******************************************************************************
* Function Name  : CAN_SCE_IRQHandler
* Description    : This function handles CAN SCE interrupt request.
* Input          : None
* Output         : None
* Return         : None
*******************************************************************************/
void CAN_SCE_IRQHandler(void)
{
}

/*******************************************************************************
* Function Name  : EXTI9_5_IRQHandler
* Description    : This function handles External lines 9 to 5 interrupt request.
* Input          : None
* Output         : None
* Return         : None
*******************************************************************************/
void EXTI9_5_IRQHandler(void)
{
}

/*******************************************************************************
* Function Name  : TIM1_BRK_IRQHandler
* Description    : This function handles TIM1 Break interrupt request.
* Input          : None
* Output         : None
* Return         : None
*******************************************************************************/
void TIM1_BRK_IRQHandler(void)
{  
//  MCL_SetFault(OVER_CURRENT);
 // TIM1_ClearITPendingBit(TIM1_IT_Break);
}

/*******************************************************************************
* Function Name  : TIM1_UP_IRQHandler
* Description    : This function handles TIM1 overflow and update interrupt 
*                  request.
* Input          : None
* Output         : None
* Return         : None
*******************************************************************************/
void TIM1_UP_IRQHandler(void)
{
//#ifdef THREE_SHUNT
  // ReEnable EXT. ADC Triggering
//  ADC1->CR2 |= 0x00008000;
  
  // Clear unwanted current sampling
 // ADC_ClearFlag(ADC1, ADC_FLAG_JEOC);
  
  // Clear Update Flag
  TIM1_ClearFlag(TIM1_FLAG_Update);
//#endif  
}

/*******************************************************************************
* Function Name  : TIM1_TRG_COM_IRQHandler
* Description    : This function handles TIM1 Trigger and commutation interrupts 
*                  requests.
* Input          : None
* Output         : None
* Return         : None
*******************************************************************************/
void TIM1_TRG_COM_IRQHandler(void)
{
}

/*******************************************************************************
* Function Name  : TIM1_CC_IRQHandler
* Description    : This function handles TIM1 capture compare interrupt request.
* Input          : None
* Output         : None
* Return         : None
*******************************************************************************/
void TIM1_CC_IRQHandler(void)
{
}

/*******************************************************************************
* Function Name  : TIM2_IRQHandler
* Description    : This function handles TIM2 global interrupt request.
* Input          : None
* Output         : None
* Return         : None
*******************************************************************************/

void TIM2_IRQHandler(void)
{
   u32 Hall_period;
   u32 polarity;
   u32 temp;

   

// Check for the source of TIMx int - Capture or Update Event - 
  
    // A capture event generated this interrupt
	  

   if ( TIM_GetFlagStatus(TIM2, TIM_FLAG_Update) == RESET )
  {
    
   switch( ReadHallState())
   {
   case STATE_1:
   TIM1->CCER &= 0x2AAA;  // Clear CC1 to CC3

   //TIM1->CCER |= (UH|WL); //Enable UH and WL 
    TIM1->CCER |= (UH|VL);

   break;

  case STATE_5:
   TIM1->CCER &= 0x2AAA;  // Clear CC1 to CC3

   //TIM1->CCER |= (UH|VL); //Enable UH and VL
    TIM1->CCER |= (WH|VL); 

   break; 
   
   case STATE_4:
   TIM1->CCER &= 0x2AAA;  // Clear CC1 to CC3

   //TIM1->CCER |= (WH|VL); //Enable WH and VL 
   TIM1->CCER |= (WH|UL);
   break;

	case STATE_6:
   TIM1->CCER &= 0x2AAA;  // Clear CC1 to CC3

   //TIM1->CCER |= (WH|UL); //Enable WH and UL 
   TIM1->CCER |= (VH|UL);

   break;

     case STATE_2:
   TIM1->CCER &= 0x2AAA;  // Clear CC1 to CC3

   //TIM1->CCER |= (VH|UL); //Enable VH and UL
   TIM1->CCER |= (VH|WL); 

   break;

   case STATE_3:
   TIM1->CCER &= 0x2AAA;  // Clear CC1 to CC3

   //TIM1->CCER |= (VH|WL); //Enable VH and WL 
   TIM1->CCER |= (UH|WL);

   break;

   default:

   TIM1->CCER &= 0x2AAA;  // Clear CC1 to CC3
   
   break;

   }
   polarity = TIM2->CCER & 0x2;
  if (polarity != 0)
  { TIM2->CCER &= 0xFFFD;
 
   }
   else
  {
   TIM2->CCER |= 0x02;

  } 
   
   Hall_period = TIM2->CCR1;

if (Hall_period != 0)
	{ //quickly PWM control just for the low speed startup,or will genetate over-shot
	if(Hall_period>=450)   
	 {hRotorFreq=360000/Hall_period;		
	  motor_inter_time = 0;
	  Motor_data = 0;}
	else
	{
	//   { //72M/1K/4 poles=18000
	   temp = (s32)(18000/(Hall_period));
	//   }
	//   else
	 //  {
	 //  temp = 0;
	//   } //temp/3 Feq,change to rpm =temp/3*60=temp*20,so Motor_data is rpm rate
	   if (motor_inter_time < 20)
	   {
	   	Motor_data += temp;
		motor_inter_time++;
	   }
       else
	   {           
	    hRotorFreq = Motor_data;
		motor_inter_time = 0;
		Motor_data = 0;
	     }
	 }	 	 	
   	}

    if(hRotorFreq<=0)
    {hRotorFreq=0;}  
   	else if(hRotorFreq >MOTOR_MAX_SPEED_RPM)
	{hRotorFreq=MOTOR_MAX_SPEED_RPM;}
   //Curr_HallState = bHallState;
   
   
   TIM_ClearFlag(TIM2, TIM_FLAG_CC1); 
  	
   }

  else//TIM_GetFlagStatus(TIM2, TIM_FLAG_Update) == SET  
  {
  
	HallTimeOut = TRUE;
//	MCL_SetFault(SPEED_FEEDBACK);
	hRotorFreq=0;
//	TIM1_CtrlPWMOutputs(DISABLE);
	State=INIT;
	StartTime++;
    TIM_ClearFlag(TIM2, TIM_FLAG_Update);  
   }
 }

/*******************************************************************************
* Function Name  : TIM3_IRQHandler
* Description    : This function handles TIM3 global interrupt request.
* Input          : None
* Output         : None
* Return         : None
*******************************************************************************/
#ifndef TIMER3_HANDLES_ENCODER
#ifndef TIMER3_HANDLES_HALL
void TIM3_IRQHandler(void)
{ 

  PID_Speed_Coefficients_update(hRotorFreq);
  TIM_ClearFlag(TIM3, TIM_FLAG_Update); 
}
#endif
#endif

/*******************************************************************************
* Function Name  : TIM4_IRQHandler
* Description    : This function handles TIM4 global interrupt request.
* Input          : None
* Output         : None
* Return         : None
*******************************************************************************/
#ifndef TIMER4_HANDLES_ENCODER
#ifndef TIMER4_HANDLES_HALL
void TIM4_IRQHandler(void)
{  
}
#endif
#endif

/*******************************************************************************
* Function Name  : I2C1_EV_IRQHandler
* Description    : This function handles I2C1 Event interrupt request.
* Input          : None
* Output         : None
* Return         : None
*******************************************************************************/
void I2C1_EV_IRQHandler(void)
{
}

/*******************************************************************************
* Function Name  : I2C1_ER_IRQHandler
* Description    : This function handles I2C1 Error interrupt request.
* Input          : None
* Output         : None
* Return         : None
*******************************************************************************/
void I2C1_ER_IRQHandler(void)
{
}

/*******************************************************************************
* Function Name  : I2C2_EV_IRQHandler
* Description    : This function handles I2C2 Event interrupt request.
* Input          : None
* Output         : None
* Return         : None
*******************************************************************************/
void I2C2_EV_IRQHandler(void)
{
}

/*******************************************************************************
* Function Name  : I2C2_ER_IRQHandler
* Description    : This function handles I2C2 Error interrupt request.
* Input          : None
* Output         : None
* Return         : None
*******************************************************************************/
void I2C2_ER_IRQHandler(void)
{
}

/*******************************************************************************
* Function Name  : SPI1_IRQHandler
* Description    : This function handles SPI1 global interrupt request.
* Input          : None
* Output         : None
* Return         : None
*******************************************************************************/
void SPI1_IRQHandler(void)
{
}

/*******************************************************************************
* Function Name  : SPI2_IRQHandler
* Description    : This function handles SPI2 global interrupt request.
* Input          : None
* Output         : None
* Return         : None
*******************************************************************************/
void SPI2_IRQHandler(void)
{
}

/*******************************************************************************
* Function Name  : USART1_IRQHandler
* Description    : This function handles USART1 global interrupt request.
* Input          : None
* Output         : None
* Return         : None
*******************************************************************************/
void USART1_IRQHandler(void)
{
}

/*******************************************************************************
* Function Name  : USART2_IRQHandler
* Description    : This function handles USART2 global interrupt request.
* Input          : None
* Output         : None
* Return         : None
*******************************************************************************/
void USART2_IRQHandler(void)
{
}

/*******************************************************************************
* Function Name  : USART3_IRQHandler
* Description    : This function handles USART3 global interrupt request.
* Input          : None
* Output         : None
* Return         : None
*******************************************************************************/
void USART3_IRQHandler(void)
{
}

/*******************************************************************************
* Function Name  : EXTI15_10_IRQHandler
* Description    : This function handles External lines 15 to 10 interrupt request.
* Input          : None
* Output         : None
* Return         : None
*******************************************************************************/
void EXTI15_10_IRQHandler(void)
{
}

/*******************************************************************************
* Function Name  : RTCAlarm_IRQHandler
* Description    : This function handles RTC Alarm interrupt request.
* Input          : None
* Output         : None
* Return         : None
*******************************************************************************/
void RTCAlarm_IRQHandler(void)
{
}

/*******************************************************************************
* Function Name  : USBWakeUp_IRQHandler
* Description    : This function handles USB WakeUp interrupt request.
* Input          : None
* Output         : None
* Return         : None
*******************************************************************************/
void USBWakeUp_IRQHandler(void)
{
}

/******************* (C) COPYRIGHT 2007 STMicroelectronics *****END OF FILE****/

