/******************** (C) COPYRIGHT 2007 STMicroelectronics ********************
* File Name          : STM32x_svpwm_3shunt.c
* Author             : IMS Systems Lab
* Date First Issued  : 21/11/07
* Description        : 3 shunt resistors current reading module
********************************************************************************
* History:
* 21/11/07 v1.0
********************************************************************************
* THE PRESENT SOFTWARE WHICH IS FOR GUIDANCE ONLY AIMS AT PROVIDING CUSTOMERS
* WITH CODING INFORMATION REGARDING THEIR PRODUCTS IN ORDER FOR THEM TO SAVE TIME.
* AS A RESULT, STMICROELECTRONICS SHALL NOT BE HELD LIABLE FOR ANY DIRECT,
* INDIRECT OR CONSEQUENTIAL DAMAGES WITH RESPECT TO ANY CLAIMS ARISING FROM THE
* CONTENT OF SUCH SOFTWARE AND/OR THE USE MADE BY CUSTOMERS OF THE CODING
* INFORMATION CONTAINED HEREIN IN CONNECTION WITH THEIR PRODUCTS.
*******************************************************************************/

/* Includes-------------------------------------------------------------------*/
#include "stm32f10x_lib.h"
#include "stm32f10x_svpwm_3shunt.h"

/* Private typedef -----------------------------------------------------------*/
/* Private define ------------------------------------------------------------*/
//the startup pulse setting
#define Pulse_INIT1	  (u16)0x250	   //15% initiation PWM period
#define Pulse_INIT2	  (u16)0x250
#define NB_CONVERSIONS 16

#define SQRT_3		1.732051
#define T		(PWM_PERIOD * 4)
#define T_SQRT3         (u16)(T * SQRT_3)

#define SECTOR_1	(u32)1
#define SECTOR_2	(u32)2
#define SECTOR_3	(u32)3
#define SECTOR_4	(u32)4
#define SECTOR_5	(u32)5
#define SECTOR_6	(u32)6




#define PHASE_A_ADC_CHANNEL     ADC_Channel_11
#define PHASE_B_ADC_CHANNEL     ADC_Channel_12
#define PHASE_C_ADC_CHANNEL     ADC_Channel_13

// Setting for sampling of VBUS and Temp after currents sampling
#define PHASE_A_MSK       (u32)((u32)(PHASE_A_ADC_CHANNEL) << 10)
#define PHASE_B_MSK       (u32)((u32)(PHASE_B_ADC_CHANNEL) << 10)
#define PHASE_C_MSK       (u32)((u32)(PHASE_C_ADC_CHANNEL) << 10)
// Settings for current sampling only
/*#define PHASE_A_MSK       (u32)((u32)(PHASE_A_ADC_CHANNEL) << 15)
#define PHASE_B_MSK       (u32)((u32)(PHASE_B_ADC_CHANNEL) << 15)
#define PHASE_C_MSK       (u32)((u32)(PHASE_C_ADC_CHANNEL) << 15)*/

// Setting for sampling of VBUS and Temp after currents sampling
#define TEMP_FDBK_MSK     (u32)((u32)(TEMP_FDBK_CHANNEL) <<15)
#define BUS_VOLT_FDBK_MSK (u32)((u32)(BUS_VOLT_FDBK_CHANNEL) <<15)
// Settings for current sampling only
//#define TEMP_FDBK_MSK     (u32)(0)
//#define BUS_VOLT_FDBK_MSK (u32)(0)

// Setting for sampling of VBUS and Temp after currents sampling
#define SEQUENCE_LENGHT    0x00100000
// Settings for current sampling only
//#define SEQUENCE_LENGHT    0x00000000

#define ADC_PRE_EMPTION_PRIORITY 1
#define ADC_SUB_PRIORITY 0

#define BRK_PRE_EMPTION_PRIORITY 0
#define BRK_SUB_PRIORITY 0

#define TIM1_UP_PRE_EMPTION_PRIORITY 1
#define TIM1_UP_SUB_PRIORITY 0

//#if(BRAKE_METHOD== FREE_WHEELING)
#define LOW_SIDE_POLARITY  TIM1_OCIdleState_Reset
//#elif(BRAKE_METHOD == SHORTED_WINDINGS)
//#define LOW_SIDE_POLARITY  TIM1_OCIdleState_Set  
//#endif

#define PWM2_MODE 0
#define PWM1_MODE 1

/* Private macro -------------------------------------------------------------*/
/* Private variables ---------------------------------------------------------*/
u8  bSector;  

u16 hPhaseAOffset;
u16 hPhaseBOffset;
u16 hPhaseCOffset;

u8 PWM4Direction=PWM2_MODE;
   
/* Private function prototypes -----------------------------------------------*/



/*******************************************************************************
* Function Name  : SVPWM_3ShuntInit
* Description    : It initializes PWM and ADC peripherals
* Input          : None
* Output         : None
* Return         : None
*******************************************************************************/
void SVPWM_3ShuntInit(void)
{ 

 

  //ADC_InitTypeDef ADC_InitStructure;
  TIM1_TimeBaseInitTypeDef TIM1_TimeBaseStructure;
  TIM1_OCInitTypeDef TIM1_OCInitStructure;
  TIM1_BDTRInitTypeDef TIM1_BDTRInitStructure;
  //NVIC_InitTypeDef NVIC_InitStructure;
  GPIO_InitTypeDef GPIO_InitStructure;

  /* ADC1, ADC2, DMA, GPIO, TIM1 clocks enabling -----------------------------*/
  
  /* ADCCLK = PCLK2/6 */
  //RCC_ADCCLKConfig(RCC_PCLK2_Div6);

  /* Enable DMA clock */
  RCC_AHBPeriphClockCmd(RCC_AHBPeriph_DMA, ENABLE);
  
  /* Enable GPIOA,GPIOB, AFIO clocks */
  RCC_APB2PeriphClockCmd(RCC_APB2Periph_AFIO | RCC_APB2Periph_GPIOA| RCC_APB2Periph_GPIOB, ENABLE);

  /* Enable TIM1 clock */
  RCC_APB2PeriphClockCmd(RCC_APB2Periph_TIM1, ENABLE);
     
  /* ADC1, ADC2, PWM pins configurations -------------------------------------*/
  GPIO_StructInit(&GPIO_InitStructure);

  /* GPIOA Configuration: Channel 1, 2, 3 and 4 Output */
  GPIO_InitStructure.GPIO_Pin = GPIO_Pin_8 | GPIO_Pin_9 | GPIO_Pin_10;
  GPIO_InitStructure.GPIO_Mode = GPIO_Mode_AF_PP;
  GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;
  GPIO_Init(GPIOA, &GPIO_InitStructure);

  /* GPIOB Configuration: Channel 1N, 2N and 3N Output */
  GPIO_InitStructure.GPIO_Pin = GPIO_Pin_13 | GPIO_Pin_14 | GPIO_Pin_15;
  GPIO_InitStructure.GPIO_Mode = GPIO_Mode_AF_PP;
  GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;
  GPIO_Init(GPIOB, &GPIO_InitStructure); 
    /* Lock GPIOB Pin13 and Pin15 Pin 14 (High sides) */
  GPIO_PinLockConfig(GPIOB, GPIO_Pin_13 | GPIO_Pin_14 | GPIO_Pin_15);
  /* GPIOB Configuration: BKIN pin */   
  GPIO_InitStructure.GPIO_Pin = GPIO_Pin_12;
  //GPIO_InitStructure.GPIO_Mode = GPIO_Mode_IPD;//not used in the opticalcouple circuit
  GPIO_InitStructure.GPIO_Mode = GPIO_Mode_AF_PP;
  GPIO_Init(GPIOB, &GPIO_InitStructure); 
  //GPIO_PinRemapConfig(GPIO_FullRemap_TIM1,ENABLE);

  //GPIO_StructInit(&GPIO_InitStructure);

     
  /* TIM1 Peripheral Configuration -------------------------------------------*/
  /* TIM1 Registers reset */
  TIM1_DeInit();
  TIM1_TimeBaseStructInit(&TIM1_TimeBaseStructure);

  /* Timer Base configuration */
  TIM1_TimeBaseStructure.TIM1_Prescaler = 0x0;
  TIM1_TimeBaseStructure.TIM1_CounterMode = TIM1_CounterMode_CenterAligned1;
  TIM1_TimeBaseStructure.TIM1_Period = PWM_PERIOD;//28.8K PWM 
  TIM1_TimeBaseStructure.TIM1_ClockDivision = TIM1_CKD_DIV2;
  
  // Initial condition is REP=0 to set the UPDATE only on the underflow
  TIM1_TimeBaseStructure.TIM1_RepetitionCounter = REP_RATE;
  TIM1_TimeBaseInit(&TIM1_TimeBaseStructure);
    /* Channel 1, 2,3 in PWM mode */   //PWM mode1:TIMx_CNT<TIMx_CCR1 Effective Output 
  TIM1_OCStructInit(&TIM1_OCInitStructure);
  TIM1_OCInitStructure.TIM1_OCMode = TIM1_OCMode_PWM1;
   //CCXE,CCXNE,ouput enable
  TIM1_OCInitStructure.TIM1_OutputState = TIM1_OutputState_Enable;
  TIM1_OCInitStructure.TIM1_OutputNState = TIM1_OutputNState_Enable;                  

  TIM1_OCInitStructure.TIM1_OCPolarity =  	TIM1_OCPolarity_High; 
  TIM1_OCInitStructure.TIM1_OCNPolarity = 	TIM1_OCNPolarity_High;         
  TIM1_OCInitStructure.TIM1_OCIdleState = 	TIM1_OCIdleState_Reset;
  TIM1_OCInitStructure.TIM1_OCNIdleState = 	LOW_SIDE_POLARITY;  
          
  TIM1_OCInitStructure.TIM1_Pulse = Pulse_INIT1; //dummy value 64/1280=5%
  TIM1_OC1Init(&TIM1_OCInitStructure); 
  TIM1_OC2Init(&TIM1_OCInitStructure);
                   
  TIM1_OCInitStructure.TIM1_Pulse = Pulse_INIT2; //=100%
  TIM1_OC3Init(&TIM1_OCInitStructure);
  TIM1_OC4Init(&TIM1_OCInitStructure);
  
  /* Enables the TIM1 Preload on CC1 Register */
  TIM1_OC1PreloadConfig(TIM1_OCPreload_Enable);
  /* Enables the TIM1 Preload on CC2 Register */
  TIM1_OC2PreloadConfig(TIM1_OCPreload_Enable);
  /* Enables the TIM1 Preload on CC3 Register */
  TIM1_OC3PreloadConfig(TIM1_OCPreload_Enable);
  /* Enables the TIM1 Preload on CC4 Register */
  TIM1_OC4PreloadConfig(TIM1_OCPreload_Enable);

  /* Automatic Output enable, Break, dead time and lock configuration*/
  TIM1_BDTRInitStructure.TIM1_OSSRState = TIM1_OSSRState_Enable;//OSSR off state select in Run
  TIM1_BDTRInitStructure.TIM1_OSSIState = TIM1_OSSIState_Enable;//OSSI off state select	in Idle
   //can't write TIMx_BDTR DTGBKEBKPAOEλTIMx_CR2 OISx/OISxN
  TIM1_BDTRInitStructure.TIM1_LOCKLevel = TIM1_LOCKLevel_1; 
  TIM1_BDTRInitStructure.TIM1_DeadTime = DEADTIME;

  TIM1_BDTRInitStructure.TIM1_Break = TIM1_Break_Enable;
  TIM1_BDTRInitStructure.TIM1_BreakPolarity = TIM1_BreakPolarity_High;
  TIM1_BDTRInitStructure.TIM1_AutomaticOutput = TIM1_AutomaticOutput_Disable;

  TIM1_BDTRConfig(&TIM1_BDTRInitStructure);

 // TIM1_SelectOutputTrigger(TIM1_TRGOSource_Update);
  
  TIM1_ClearITPendingBit(TIM1_IT_Break);
//  TIM1_ITConfig(TIM1_IT_Break,ENABLE);
  
  /* TIM1 counter enable */
  TIM1_Cmd(ENABLE);

    /* Main Output Enable */
  //TIM1_CtrlPWMOutputs(ENABLE);

  // Resynch to have the Update evend during Undeflow
  TIM1_GenerateEvent(TIM1_EventSource_Update);
  
  // Clear Update Flag
  TIM1_ClearFlag(TIM1_FLAG_Update);
  
  TIM1_ITConfig(TIM1_IT_Update, DISABLE);
  
  TIM1_ITConfig(TIM1_IT_CC4,DISABLE);
    /* Enable the Update Interrupt */
 
    
  /* Enable the TIM1 BRK Interrupt */
 // NVIC_InitStructure.NVIC_IRQChannel = TIM1_BRK_IRQChannel;
 // NVIC_InitStructure.NVIC_IRQChannelPreemptionPriority = BRK_PRE_EMPTION_PRIORITY;
 // NVIC_InitStructure.NVIC_IRQChannelSubPriority = BRK_SUB_PRIORITY;
 // NVIC_InitStructure.NVIC_IRQChannelCmd = ENABLE;
 // NVIC_Init(&NVIC_InitStructure); 

     
} 

/******************* (C) COPYRIGHT 2007 STMicroelectronics *****END OF FILE****/  
